Co za inba się odwaliła to ja nawet nie.
Mój brat, lvl 25, zamknął się w pokoju i nie chce wyjść. Próbowałem z nim pogadać przez drzwi, to krzyknął tylko, że gardzi normictwem i z nikim nie będzie gadał, bo robi jakiś eksperyment.
Ok, mówię, powiem mamie, że wyzywasz. Więc lecę do matki na skargę, no nie, i ona mówi, że z nim pogada. To idę z nią podsłuchać rozmowę. A ten krzyczy znowu przez drzwi, że mama jest p0lką, on nią gardzi, bo nie jest dziewicą i nie chce od niej żadnych pierożków. Ponadto, że pewnie miała milion bolców na boku i zdradza ojca. Krzyczał tak głośno, że tate przyszedł i zapytał co się dzieje. Po streszczeniu całej sytuacji ojciec tak się wku$wił, że wywalił drzwi z kopa i wlazł do jego pokoju. Powiedział do brata, że jak śmie się tak odzywać do matki i że natychmiast ma ją przeprosić. A ten debil z ryjem do ojca i gada coś od rzeczy, że jakiś biały rycerz, że jakiś bankomat bety, że loszki to ku^wy xD Ryczy w niebogłosy, że to niesprawiedliwe, że morda równa się wszystko, że przegrał życie. Zaczął ojca wyzywać, że dostał od niego gówniane geny i przez niego ma 170 cm, 50 kg nadwagi, brak pracy i zainteresowań xD Matka w płacz i histeria, bo debil oszalał i trzeba dzwonić po czubków, niech go zabierają do szpitala. Ojciec powiedział debilowi, że zepsuł nam święta. Przutulił matkę i zaczął ją pocieszać, a ten debil do ojca, że spermiarz i orbiter i psuje rynek. Ojciec nie zdzierżył i przypi%rdolił mu w jape, teraz czekamy na karetkę xD